@@ -12,6 +12,7 @@ class InstaViewer:
         self.session = requests.Session()
         self.username = username
         self.user_id = None
+        self.token = None
         self.setup()
 
     def setup(self):
@@ -28,10 +29,14 @@ class InstaViewer:
         # save user id
         self.user_id = re.search(r"app_insta\.user_id = '(\d+)'", response.text).group(1)
 
+        # save token
+        self.token = re.search(r"app_insta\.token = \"(\w+)\"", response.text).group(1)
+
     def get_stories(self, format=None):
         response = self.session.post(f"{URL}/search", data={
             "getStories": "true", 
-            "userId": self.user_id
+            "userId": self.user_id,
+            "token": self.token
         })
         response.raise_for_status()
         if format == "json":
@@ -41,7 +46,8 @@ class InstaViewer:
     def get_posts(self, format=None):
         response = self.session.post(f"{URL}/search", data={
             "getPosts": "true", 
-            "userId": self.user_id
+            "userId": self.user_id,
+            "token": self.token
         })
         response.raise_for_status()
         if format == "json":
